Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1876)

Unified Diff: content/browser/renderer_host/render_process_host_impl.h

Issue 1832813002: Add mojom module suffix in .mojom files in content. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Address Tom's comment Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/renderer_host/render_process_host_impl.h
diff --git a/content/browser/renderer_host/render_process_host_impl.h b/content/browser/renderer_host/render_process_host_impl.h
index ccb83b2a16c3919a1797502f44987c1c39051172..7580068dff19cda345e3087b6a0e029e7ebf2f96 100644
--- a/content/browser/renderer_host/render_process_host_impl.h
+++ b/content/browser/renderer_host/render_process_host_impl.h
@@ -70,7 +70,10 @@ class RenderWidgetHostImpl;
class RenderWidgetHostViewFrameSubscriber;
class StoragePartition;
class StoragePartitionImpl;
+
+namespace mojom {
class StoragePartitionService;
+}
typedef base::Thread* (*RendererMainThreadFactoryFunction)(
const InProcessChildThreadParams& params);
@@ -304,7 +307,7 @@ class CONTENT_EXPORT RenderProcessHostImpl
void RegisterMojoServices();
void CreateStoragePartitionService(
- mojo::InterfaceRequest<StoragePartitionService> request);
+ mojo::InterfaceRequest<mojom::StoragePartitionService> request);
// Control message handlers.
void OnShutdownRequest();
@@ -488,7 +491,8 @@ class CONTENT_EXPORT RenderProcessHostImpl
// for UMA.
int max_worker_count_;
// Context shared for each PermissionService instance created for this RPH.
scoped_ptr<PermissionServiceContext> permission_service_context_;
// This is a set of all subscription targets valuebuffers in the GPU process
@@ -488,7 +491,8 @@ class CONTENT_EXPORT RenderProcessHostImpl
// for UMA.
int max_worker_count_;
- // Context shared for each PermissionService instance created for this RPH.
+ // Context shared for each mojom::PermissionService instance created for this
+ // RPH.
scoped_ptr<PermissionServiceContext> permission_service_context_;
// This is a set of all subscription targets valuebuffers in the GPU process

Powered by Google App Engine
This is Rietveld 408576698